var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { useContext } from 'react';
import { ThemeContext, ThemeProvider as Provider, } from 'styled-components';
import merge from 'deepmerge';
import Color from 'color';
export var defaultTheme = {
    colors: {
        primary: '#C7C7CB',
        secondary: '#E3E3E5',
        primaryText: '#76767C',
        secondaryText: '#B9B9BC',
        red: '#db7f7f',
        orange: '#E8A72C',
        yellow: '#EFEF2C',
        green: '#24D174',
        teal: '#09D0B1',
        blue: '#2CB2E8',
        purple: '#A913E0',
        pink: '#FC42AD',
        brown: '#814306',
        black: '#151515',
        grey: '#A0A0A0',
        white: '#fff',
    },
    greyscale: {
        lightest: '#FAFAFB',
        lighter: '#F5F5F5',
        light: '#ECECEC',
        medium: '#D4D4D4',
        dark: '#C7C7CB',
        darker: '#76767C',
        darkest: '#393941',
    },
    global: {
        fontSize: '14px',
        fontFamily: "'Titillium Web','Helvetica Neue',Arial,Helvetica,sans-serif;",
    },
    font: {
        h1: {
            fontSize: 24,
            fontWeight: 600,
            lineHeight: '44px',
        },
        h2: {
            fontSize: 18,
            fontWeight: 400,
        },
        h3: {
            fontSize: 16,
            fontWeight: 600,
        },
    },
    sizes: {
        borderRadius: '1.5em',
        borderRadiusInput: '1.5em',
        padding: {
            normal: '0.5em',
            extra: '1rem 2.5rem',
        },
        scale: {
            mini: 11,
            tiny: 12,
            small: 13,
            medium: 14,
            large: 16,
            big: 18,
            huge: 20,
            massive: 24,
        },
        width: {
            sm: 0,
            md: 723,
            lg: 933,
            xl: 1127,
        },
    },
    breakpoints: {
        sm: 576,
        md: 768,
        lg: 992,
        xl: 1200,
    },
};
var darken = function (c, value) {
    var _c = c.darken(value);
    if (_c.lightness() === 0) {
        return _c.lightness(5);
    }
    return _c;
};
var lighten = function (c, value) {
    var _c = c.lighten(value);
    if (_c.lightness() === 100) {
        return _c.lightness(95);
    }
    return _c;
};
export var createColors = function (colors) {
    var res = {};
    for (var key in colors) {
        if (colors.hasOwnProperty(key)) {
            var cHexOrRecord = colors[key];
            var cHex = typeof cHexOrRecord === 'string' ? cHexOrRecord : cHexOrRecord.default;
            var c = Color(cHex);
            if (key.endsWith('Text')) {
                res[key] = {
                    default: cHex,
                    active: (c.isDark() ? darken(c, 0.2) : lighten(c, 0.4)).hex(),
                    hover: (c.isDark() ? lighten(c, 0.4) : darken(c, 0.2)).hex(),
                    light: lighten(c, 0.5).hex(),
                    dark: darken(c, 0.2).hex(),
                    verylight: lighten(c, 0.75).hex(),
                    highlighted: lighten(c, 0.624).hex(),
                    highlightedHover: lighten(c, 0.579).hex(),
                    saturated: c.saturate(1.52).lighten(0.83).hex(),
                    disabled: (c.isDark()
                        ? c.saturate(-0.07).lighten(0.44)
                        : c.saturate(-0.07).darken(0.44)).hex(),
                    verytransparent: c.alpha(0.25).toString(),
                    transparent: c.alpha(0.5).toString(),
                    blured: lighten(c, 0.624).alpha(0.2).toString(),
                };
                continue;
            }
            res[key] = {
                default: cHex,
                active: (c.isLight() ? darken(c, 0.1) : lighten(c, 0.2)).hex(),
                hover: (c.isLight() ? lighten(c, 0.2) : darken(c, 0.1)).hex(),
                light: lighten(c, 0.65).hex(),
                dark: darken(c, 0.3).hex(),
                verylight: lighten(c, 0.95).hex(),
                highlighted: lighten(c, 0.624).hex(),
                highlightedHover: lighten(c, 0.579).hex(),
                saturated: c.saturate(1.52).lighten(0.83).hex(),
                disabled: c.saturate(-0.07).lighten(0.44).hex(),
                verytransparent: c.alpha(0.25).toString(),
                transparent: c.alpha(0.5).toString(),
                blured: lighten(c, 0.624).alpha(0.2).toString(),
            };
            // Lazy overwrite of generated values
            if (typeof cHexOrRecord === 'object') {
                res[key] = __assign(__assign({}, res[key]), cHexOrRecord);
            }
        }
    }
    return res;
};
export var createTheme = function (theme) {
    var _a = theme
        ? merge(defaultTheme, theme)
        : defaultTheme, colors = _a.colors, rest = __rest(_a, ["colors"]);
    return __assign({ colors: createColors(colors) }, rest);
};
export var defaultCreatedTheme = createTheme();
export default defaultCreatedTheme;
export var useTheme = function () { return useContext(ThemeContext) || defaultCreatedTheme; };
export var ThemeProvider = Provider;
